@@ -22,6 +22,3 @@ class NotBot():
     def notify_async(self, text):
         notify_thread = threading.Thread(target=self.notify, args=(text,))
         notify_thread.start()
-
-notBot = NotBot('1865052104:AAHmOyOkYDcaXx0TWCBtwm1r29pTFkhlx7s')
-notBot.notify_async('Fala tu')
